import 'dart:io';

import 'package:path/path.dart' as path;

import '../globals.dart';
import 'generated_config.dart';

final String cliVersion = versionName;

enum CliEnvironment { debug, release }

CliEnvironment cliEnvironment() {
  return release == 1 ? CliEnvironment.release : CliEnvironment.debug;
}

void cliPrint(String logString) {
  cliPrints(logString, true);
}

void cliPrints(String logString, bool isReleasePrint) {
  if (cliEnvironment() == CliEnvironment.debug) {
    print(logString);
  } else {
    if (isReleasePrint) {
      printStatus(logString);
    }
  }
}

Future<void> copyPath(String from, String to) async {
  if (_doNothing(from, to)) {
    return;
  }
  await Directory(to).create(recursive: true);
  await for (final file in Directory(from).list(recursive: true)) {
    final copyTo = path.join(to, path.relative(file.path, from: from));
    if (file is Directory) {
      await Directory(copyTo).create(recursive: true);
    } else if (file is File) {
      await File(file.path).copy(copyTo);
    } else if (file is Link) {
      await Link(copyTo).create(await file.target(), recursive: true);
    }
  }
}

bool _doNothing(String from, String to) {
  if (path.canonicalize(from) == path.canonicalize(to)) {
    return true;
  }
  return false;
}
